#!/usr/bin/python3
"""
Ubuntu charm functional test.  Take note that the Ubuntu
charm does not have any relations or config options
to exercise.
"""

import amulet
from charmhelpers.contrib.amulet.utils import AmuletUtils
import logging


def ubuntu_basic_deployment(series):
    """ Common test routines to run per-series. """

    # Initialize
    seconds = 900
    u = AmuletUtils(logging.DEBUG)
    d = amulet.Deployment(series=series)
    d.add('ubuntu')
    unit = 'ubuntu/0'
    lsb_command = 'lsb_release -cs'

    # Deploy services, wait for started state.  Fail or skip on timeout.
    try:
        d.setup(timeout=seconds)
    except amulet.helpers.TimeoutError:
        message = 'Deployment timed out ({}s)'.format(seconds)
        amulet.raise_status(amulet.SKIP, msg=message)
    except:
        raise

    # Confirm Ubuntu release name from the unit.
    u.log.debug('Command:  {}'.format(lsb_command))
    output, code = d.sentry.unit[unit].run(lsb_command)
    u.log.debug('Output:  {}'.format(output))

    if (code != 0):
        message = 'Command FAIL:  {}'.format(lsb_command)
        u.log.error(message)
        amulet.raise_status(amulet.FAIL, msg=message)
    else:
        if series in output:
            message = 'Series:  OK'
            u.log.info(message)
        else:
            message = 'Series:  FAIL ({})'.format(output)
            u.log.error(message)
            amulet.raise_status(amulet.FAIL, msg=message)
